@@ -25,10 +25,9 @@ class AES:
         self.main_key = data.get('mainKey')
         self.build = data.get('build')
         self.version = re.search(r'\d\d.\d\d', self.build)[0] if self.build else None
-
         try:
             self.updated = datetime.strptime(data.get('updated'), '%Y-%m-%dT%H:%M:%S%z')
-        except ValueError:
+        except (ValueError, ValueError):
             self.updated = None
 
         self.dynamic_keys = []
